import axios from "axios";
import { defineStore } from "pinia";

export const useAuthStore = defineStore("auth", {
  state: () => ({
    token: localStorage.getItem('token') || '',
    adminToken: sessionStorage.getItem('adminToken') || ''
  }),
  actions: {
    setToken(token: string) {
      this.token = token;
      localStorage.setItem('token', token);
    },
    async clearToken() {
      try {
        const formData = new FormData;
        formData.append("token", this.token);
        await axios.post('/api/auth/logout', formData);
      } catch (e) {
      }
      this.token = '';
      localStorage.removeItem('token');
    },
    setAdminToken(token: string) {
      this.adminToken = token;
      sessionStorage.setItem('adminToken', token);
    },
    clearAdminToken() {
      this.adminToken = '';
      sessionStorage.removeItem('adminToken');
    }
  },
  getters: {
    isAuthenticated: (state) => !!state.token,
    isAdmin: (state) => !!state.adminToken,
  },
});
